@@ -22,6 +22,7 @@ from . elements import (
     Location,
     Nilsimsa,
     NumericRange,
+    Pickle,
     Schema,
     String,
     Text,
@@ -40,6 +41,8 @@ __all__ = [
     'Location',
     'MultipleValueRangeProcessor',
     'NumericRange',
+    'Pickle',
+    'Nilsimsa',
     'Schema',
     'String',
     'Text',
